aboutsummaryrefslogtreecommitdiffstats
path: root/activerecord/test/binary_test.rb
diff options
context:
space:
mode:
Diffstat (limited to 'activerecord/test/binary_test.rb')
-rw-r--r--activerecord/test/binary_test.rb6
1 files changed, 3 insertions, 3 deletions
diff --git a/activerecord/test/binary_test.rb b/activerecord/test/binary_test.rb
index 27f4881e50..8ba758a892 100644
--- a/activerecord/test/binary_test.rb
+++ b/activerecord/test/binary_test.rb
@@ -18,9 +18,9 @@ class BinaryTest < Test::Unit::TestCase
# limited to 8KB.
#
# Without using prepared statements, it makes no sense to test
- # BLOB data with DB2, because the length of a statement is
- # limited to 32KB.
- unless %w(SQLServer DB2 OCI).include? ActiveRecord::Base.connection.adapter_name
+ # BLOB data with DB2 or Firebird, because the length of a statement
+ # is limited to 32KB.
+ unless %w(SQLServer DB2 OCI Firebird).include? ActiveRecord::Base.connection.adapter_name
def test_load_save
bin = Binary.new
bin.data = @data